// lab.js version 1.14.0 (c) 2023 Peter Hutten-Czapski
// this is the js that supports the UI for the Ontario Lab Form
// some functions require jQuery to be loaded
// use at your own risk

// ********* globals ******** //
var pi = "INSTRUCTIONS: ";
var fa = "Nothing to eat or drink, except for water, for 10 hours prior to the test. ";
var dr = "Take your medication AFTER getting your blood drawn. ";
var needToConfirm = false;

// ********* UI functions ******** //
function flip(x) {
    if (document.getElementById(x).value == '') {
        document.getElementById(x).value = 'X';
    } else {
        document.getElementById(x).value = '';
    }
}

function key(evt, x) {
    var charCode = (evt.which) ? evt.which : event.keyCode
    // any key press except tab will constitute a value change to the checkbox
    if (charCode != 9) {
        flip(x);
        return false;
    }
}

function checkGender() {
    // This form only supports M and F designations, leave O U T unchecked
    document.getElementById('Male').value = '';
    document.getElementById('Female').value = '';
    if (document.getElementById('PatientGender').value == 'M') {
        document.getElementById('Male').value = 'X';
    } else if (document.getElementById('PatientGender').value == 'F') {
        document.getElementById('Female').value = 'X';
    }
}
// ********* scripts to confirm closing of window if it hadn't been saved yet ********* //

document.onkeyup = setDirtyFlag;

function setDirtyFlag() {
    needToConfirm = true;
}

function releaseDirtyFlag() {
    needToConfirm = false;
}
window.onbeforeunload = confirmExit;

function confirmExit() {
    if (needToConfirm) {
        return "You have attempted to leave this page. If you have made any changes to the fields without clicking the Save button, your changes will be lost. Are you sure you want to exit this page?";
    }
}

function formPrint() {
    //checkProvider();
    window.print();
}

function textAreaAdjust(element) {
    element.style.height = "1px";
    element.style.height = (10 + element.scrollHeight) + "px";
}

function add(x, test) {
    if (document.getElementById(x).value.indexOf(test) == -1) {
        document.getElementById(x).value += test
    }
}

function checkProvider() {
    // Check who has opened the eForm
    if ((document.getElementById('user_ohip_no').value.length < 1) || (document.getElementById('user_ohip_no').value < 1000)) {
        // the form is being filled by someone on the doctors authority
        document.lab.txtPhysicianNumber.value = document.lab.PatientMDsOHIP.value;
        document.lab.physician.value = document.lab.doctor.value;
        document.lab.txtPhysicianNumber.value = document.lab.PatientMDsOHIP.value;
    }
    if (document.lab.physician.value != document.lab.doctor.value) {
        // add and highlight the option to cc to the doctor on record
        document.getElementById('CCMD1').innerHTML += "<input type='checkbox' name='md1' id='md1' title=document.lab.doctor.value \
        onClick=\"\
        document.lab.CopyTo.value +=  document.lab.doctor.value + ' Dr, OHIP: ' + document.lab.PatientMDsOHIP.value +' Fax:' + document.lab.txtPhysicianFax.value;\
        document.lab.chkCopyToPhysician.value='X';\
        \">Copy to Patients Doctor<br>";
        hilite('CCMD1');
        document.getElementById('md1').checked = true;
        document.lab.CopyTo.value += document.lab.doctor.value + ' Dr, OHIP:' + document.lab.PatientMDsOHIP.value + ' Fax:' + document.lab.txtPhysicianFax.value;;
        document.lab.chkCopyToPhysician.value = 'X';
    }
}

function clearMe() {
    for (i = 0; i < document.lab.elements.length; i++) {
        if (document.lab.elements[i].value == 'X') {
            document.lab.elements[i].value = '';
        }
        if (document.lab.elements[i].type == 'checkbox') {
            document.lab.elements[i].checked = false;
        }
    }
    document.getElementById('subject').value = '';
    document.getElementById('OtherTests').value = '';
    document.getElementById('Instructions').value = '';
    document.getElementById('CopyTo').value = '';
    document.getElementById('chkOHIP').value = 'X';
    checkGender();
    localise();
}
// ********* Signature functions ******** //
function SignForm2() {
    //stamp by delegation model 
    var provNum = '';
    var userBillingNo = document.getElementById('user_ohip_no').value;
    if (parseInt(userBillingNo) > 100) {
        // then a valid billing number so use the current user id 
        provNum = document.getElementById('user_id').value;
        if (provNum != document.getElementById('doctor_no').value && !!document.getElementById('doctor')) {
            document.getElementById('doctor').value = document.getElementById('CurrentUserName').value + ' CC: ' + document.getElementById('doctor').value;
        }
    } else {
        provNum = document.getElementById('doctor_no').value;
    }
    document.getElementById('Stamp').src = '../eform/displayImage.do?imagefile=consult_sig_' + provNum + '.png';
}

function toggleMe() {
    if (document.getElementById("Stamp").src.indexOf("BNK.png") > 0) {
        SignForm2()
    } else {
        document.getElementById("Stamp").src = "../eform/displayImage.do?imagefile=BNK.png";
    }
}
// ********* Set Tickler reminder for future date (aka loop closer) UI functions ******** //
Date.prototype.addDays = function(days) {
    var dat = new Date(this.valueOf());
    dat.setDate(dat.getDate() + days);
    return dat;
}

Date.prototype.addMonths = function(months) {
    var dat = new Date(this.valueOf());
    dat.setMonth(dat.getMonth() + months);
    return dat;
}

function addMonths(months) {
    var d = new Date();
    d = d.addMonths(months);
    var mth = ((d.getMonth() + 1) < 10) ? ("0" + (d.getMonth() + 1)) : (d.getMonth() + 1);
    var day = d.getDate() > 10 ? d.getDate() : ("0" + d.getDate());
    var newD = d.getFullYear() + "-" + mth + "-" + day;
    document.lab.Tickler_date.value = newD;
}

function addDays(numDays) {
    var d = new Date();
    d = d.addDays(numDays);
    var mth = ((d.getMonth() + 1) < 10) ? ("0" + (d.getMonth() + 1)) : (d.getMonth() + 1);
    var day = d.getDate() > 10 ? d.getDate() : ("0" + d.getDate());
    var newD = d.getFullYear() + "-" + mth + "-" + day;
    document.lab.Tickler_date.value = newD;
}

ticklerReminder = function() {
    var patient_id = document.getElementById('patient_id').value;
    var user_id = document.getElementById('user_id').value;
    var ticklerDate = $('#Tickler_date').val();
    var ticklerMsg = "Review labs. " + $('#Tickler_msg').val();
    sendTickler(patient_id, ticklerMsg, user_id, ticklerDate);
    if (ticklerDate == '') {
        return ("ERROR: Tickler reminder date is blank.  Please correct before proceeding.");
    }
}

sendTickler = function(demographicNo, message, taskAssignedTo, ticklerDate) {
    var ticklerToSend = {};
    ticklerToSend.demographicNo = demographicNo;
    ticklerToSend.message = message;
    ticklerToSend.taskAssignedTo = taskAssignedTo;
    ticklerToSend.serviceDate = ticklerDate;
    jQuery.ajax({
        type: "POST",
        url: '../ws/rs/tickler/add',
        dataType: 'json',
        contentType: 'application/json',
        data: JSON.stringify(ticklerToSend),
        success: processTicklerCallBack
    });
}

processTicklerCallBack = function(data) {
    if (data.success) {
        alert("Lab reminder Tickler created and assigned to you.");
    } else {
        alert("ERROR: Tickler failed. Please create tickler manually.");
    }
}

calculateTicklerDays = function() {
    if (jQuery.trim($('#Tickler_date').val()).length > 0) {
        // calculate future date for Tickler
        var t = new Date(); // today
        var d = new Date(Date.parse(jQuery.trim($('#Tickler_date').val()))); // chosen date or (today + add) - days
        var i = ((Math.floor((d - t) / (1000 * 60 * 60 * 24))) + 2); // days forward from today
        d.setDate(d.getDate());
        $("#Tickler_date").val(d.toISOString().substring(0, 10));
        var NewTickler = document.getElementById('Tickler_date').value;
        alert("Once you click Set Tickler button, a reminder will be set for " + i + " day(s) from today.  Expect Lab result(s) by " + $('#Tickler_date').val() + ". Click the Set Tickler button to create reminder now.");
    }
}

// ******** Costing ********* //	
function StartAddIfMissingTitle(x, content) {
    document.getElementById(x).title = content
}
$("#GlucoseFasting").attr('title', 'Cost: $1.28');
$("#GlucoseRandom").attr('title', 'Cost: $1.28');
$("#HbA1C").attr('title', 'Cost: $7.25');
$("#Creatinine").attr('title', 'Cost: $1.28');
$("#UricAcid").attr('title', 'Cost: $1.16');
$("#Sodium").attr('title', 'Cost: $1.16');
$("#Potassium").attr('title', 'Cost: $1.16');
$("#ALT").attr('title', 'Cost: $1.28');
$("#ALP").attr('title', 'Cost: $1,57');
$("#Bilirubin").attr('title', 'Cost: $1.55');
$("#Albumin").attr('title', 'Cost: $1.55');
$("#Lipids").attr('title', 'Cost: $21,31');
$("#ACR").attr('title', 'Cost: $11,41');
$("#Urinalysis").attr('title', 'Cost: $2.15');
$("#NeonatalBilirubin").attr('title', 'Cost: $1.55');
$("#CBC").attr('title', 'Cost: $3.98');
$("#PregnancyTestUrine").attr('title', 'Cost: $2.78');
$("#Mono").attr('title', 'Cost: $17,10');
$("#PTINR").attr('title', 'Cost: $12,07');
$("#Rubella").attr('title', 'Cost: $10,00');
$("#PrenatalAntibody").attr('title', 'Cost: $10,00');
$("#RepeatPrenatal").attr('title', 'Cost: $10,00');
$("#chkMicro_Cervical").attr('title', 'Cost: $11.09');
$("#chkMicro_Vaginal").attr('title', 'Cost: $11.09');
$("#chkMicro_Chlamydia").attr('title', 'Cost: $16.46');
$("#chkMicro_VaginalRectalGroupBStrep").attr('title', 'Cost: $15.40');
$("#chkMicro_GC").attr('title', 'Cost: $28.85 - 11.09');
$("#chkMicro_Sputum").attr('title', 'Cost: $11.09');
$("#chkMicro_Throat").attr('title', 'Cost: $3.10');
$("#chkMicro_Wound").attr('title', 'Cost: $12.93');
$("#chkMicro_Other").attr('title', 'Cost: $12.93');
$("#UrineCulture").attr('title', 'Cost: $10.34 + $9.55/org + $11.55/Ab Sus');
$("#StoolCS").attr('title', 'Cost: $17.37 + $14.42/org');
$("#StoolOP").attr('title', 'Cost: $9.12');
$("#Hepatitis_Acute").attr('title', 'Cost: $36.12');
$("#Hepatitis_Chronic").attr('title', 'Cost: $47.26');
$("#HepA").attr('title', 'Cost: $10.25');
$("#HepB").attr('title', 'Cost: $10.25');
$("#HepC").attr('title', 'Cost: $10.25');
$("#Hepatitis_ImmuneStatus").attr('title', 'Cost: $47.26');
$("#chkPSA_TotalPSA").attr('title', 'Cost: $14,35');
$("#chkPSA_Insured").attr('title', 'Cost: $14,35 insured if known or suspected prostate cancer');
$("#chkPSA_Uninsured").attr('title', 'Cost: $35.00');
$("#chkVitaminD_Uninsured").attr('title', 'Cost: $39.00');
$("#chkVitaminD_Insured").attr('title', 'Cost: $11.66 insured for: osteoporosis, rickets, osteopenia, malabsorption syndromes and  renal disease, or for persons who are on medications that affect vitamin D metabolism. ');
setInterval(function calculateCost() {
    $('#Costs').val(0);
    StartAddIfMissingTitle('Costs', "");
    var othertests = $('#OtherTests').val();
    var OtherTests = othertests.toUpperCase();
    var match = OtherTests.search("AST|PHOSPHATE|PO4|URIC|LDH|LACTATE DEHYDROGENASE");
    if ((match != -1) || (($('#Sodium').val() == 'X') || ($('#Potassium').val() == 'X') || ($('#Creatinine').val() == 'X') || ($('#Albumin').val() == 'X') || ($('#ALP').val() == 'X') || ($('#ALT').val() == 'X') || ($('#Bilirubin').val() == 'X') || ($('#GGT').val() == 'X') || ($('#TProtein').val() == 'X') || ($('#Calcium').val() == 'X') || ($('#CreatineKinase').val() == 'X') || ($('#GlucoseRandom').val() == 'X') || ($('#GlucoseFasting').val() == 'X'))) {
        newcost = Math.round(($('#Costs').val() * 1) + 15.62);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Base Chemistry Fee: $14.28\n");
    }
    if ($('#Sodium').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.16);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Na: $1.16\n");
    }
    if ($('#Potassium').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.16);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "K: $1.16\n");
    }
    if ($('#Creatinine').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "eGFR: $1.28\n");
    }
    if ($('#Albumin').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.55);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Alb: $1.55\n");
    }
    if ($('#ALP').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.57);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ALP: $1.57\n");
    }
    if ($('#ALT').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ALT: $1.28\n");
    }
    if ($('#Bilirubin').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.55);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "BILI: $1.55\n");
    }
    if ($('#GGT').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.66);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "GGT: $1.66\n");
    }
    if ($('#PrenatalAntibody').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Prenatal Antibodies: $10.00\n");
    }
    if ($('#RepeatPrenatal').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Repeat Prenatal Antibodies: $10.00\n");
    }
    if ($('#NeonatalBilirubin').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.55);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Neonatal Bili: $1.55\n");
    }
    if ($('#UricAcid').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.16);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Uric Acid: $1.16\n");
    }
    if ($('#chkVitaminD_Insured').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 11.65);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Vit D: $11.66\n");
    }
    if ($('#chkVitaminD_Uninsured').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 39.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Vit D: $39.00\n");
    }
    if ($('#HepC').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Hep C: $10.00\n");
    }
    if ($('#Hepatitis_ImmuneStatus').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 47.26);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Hepatitis Immune Status: $47.26\n");
    }
    if ($('chkMicro_Other').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 22.50);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Microbiology: $11.09 - 27.73\n");
    }
    if ($('#TProtein').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.60);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "TProtein: $1.60\n");
    }
    if ($('#Calcium').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.55);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Ca: $1.55\n");
    }
    if ($('#CreatineKinase').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.88);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CK: $1.88\n");
    }
    if ($('#CBC').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 3.98);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CBC: $3.98\n");
    }
    if ($('#PTINR').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 12.07);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "INR: $12.07\n");
    }
    if ($('#Ferritin').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.12);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Ferritin: $10.12\n");
    }
    if ($('#GlucoseFasting').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "FBS: $1.28\n");
    }
    if ($('#GlucoseRandom').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "RBS: $1.28\n");
    }
    if ($('#GTTGDMScreen').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.03);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "50G GTT: $10.03\n");
    }
    if ($('#GTTGDMConfirmation').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 15.84);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "75G GTT: $15.84\n");
    }
    if ($('#HbA1C').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 7.25);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "A1C: $7.25\n");
    }
    if ($('#ACR').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 11.41);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ACR: $11.41\n");
    }
    if ($('#Lipids').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 21.31);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "LipidProfile: $21.31\n");
    }
    if ($('#Lipid_FU').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 14.44);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "LipidFU: $14.44\n");
    }
    if ($('#Lipid_ApoB').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 16.60);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ApoB: $16.60\n");
    }
    if ($('#MonitorThyroidRx').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 9.90);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "TSH: $9.90\n");
    }
    if ($('#TSH').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 22.02);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "TSH/T4: $22.02\n");
    }
    if ($('#SuspectHyperthyroidism').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 34.14);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "TSH/T4/T3: $34.14\n");
    }
    if ($('#chkPSA_Insured').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 14.35);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "PSA: $14.35\n");
    }
    if ($('#chkPSA_Uninsured').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 35.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "PSA: $35.00\n");
    }
    if ($('#bHCG').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 16.30);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "SerumPregTest: $16.30\n");
    }
    if ($('#PregnancyTestUrine').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 15.30);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "UrinePregTest: $15.30\n");
    }
    if (($('#FIT_CSP').val() == 'X') || ($('#FIT_Other').val() == 'X')) {
        newcost = Math.round(($('#Costs').val() * 1) + 19.60);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "FIT: $19.60\n");
    }
    if ($('#ECG').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 32.47);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ECG: $32.47\n");
    }
    if ($('#Holter').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 89.19);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ECG: $89.19\n");
    }
    if ($('#UrineCulture').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 40.73);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "UrineCulture: $40.73 ($10.34 + $9.55/org + $11.55/Ab Sus)\n");
    }
    if ($('#Urinalysis').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 2.15);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "UrineMacroMicro: $2.15\n");
    }
    if ($('#UrineMacroscopicCultureIfPyuriaOrNitrate').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 48.15);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "UrineMacroCulture: $48.15 ($26.99 + $9.55/org + $11.55/Ab Sus)\n");
    }
    if ($('#UrineMacroscopicOnly').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 7.42);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "UrineMacro: $7.42\n");
    }
    if ($('#UrineMicroscopicOnly').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 7.17);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "UrineMicro: $7.17\n");
    }
    if ($('#chkMicro_VaginalRectalGroupBStrep').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 15.40);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "GBS: $15.40\n");
    }
    if ($('#chkMicro_Chlamydia').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 16.46);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Chlamydia: $16.46\n");
    }
    if ($('#StoolCS').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 17.37);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Stool Culture: $17.37 + $14.42/org\n");
    }
    if ($('#CDToxin').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 16.64);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CDiff: $16.64\n");
    }
    if ($('#StoolOP').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 9.12);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "StoolOP: $9.12\n");
    }
    if ($('#StoolOPHighRisk').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 93.86);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "StoolOPX2: $93.86\n");
    }
    if ($('#DermatophyteCulture').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 21.41);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Dermatophyte Culture: $21.41\n");
    }
    if ($('#FungusKOHPrep').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 13.76);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Fungal KOH: $13.76\n");
    }
    if ($('#HBsAg').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.40);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HBsAg: $10.40\n");
    }
    if ($('#Hepatitis_Acute').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 36.12);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Acute hepatitis: $36.12\n");
    }
    if ($('#Hepatitis_Chronic').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 47.20);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Chronic hepatitis: $47.20\n");
    }
    if ($('#HepA').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.25);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HepA status: $10.25\n");
    }
    if ($('#HepB').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 10.25);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HepB Status: $10.25\n");
    }
    if (($('#HIVNominal').val() == 'X') || ($('#HIVNonNominal').val() == 'X')) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HIV: ?$10.00\n");
    }
    if ($('#chkMicro_Throat').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 3.10);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Throat Swab: $3.10\n");
    }
    if ($('#chkMicro_Wound').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 57.57);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Sup Wound Cult: $57.57 ($12.93-62.34)\n");
    }
    if ($('#DeepWound').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 57.57);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Deep Wound Cult: $57.57 ($12.93-62.34)\n");
    }
    if ($('#chkMicro_Sputum').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 43.86);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "BV+Candida: $43.86 ($11.09-48.80)\n");
    }
    if ($('#chkMicro_Vaginal').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 43.86);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "BV+Candida: $43.86 ($11.09-48.80)\n");
    }
    if ($('#VaginitisChronic').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 24.35);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Vaginitis Chronic: $24.35 ($11.09-11.09)\n");
    }
    if ($('#Trichomonas').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 15.19);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Trichomonas: $15.19 ($11.63-11.09)\n");
    }
    if ($('#chkMicro_GC').val() == 'X') {
        newcost = Math.round(($('#Costs').val() * 1) + 28.85);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "GC: $28.85\n");
    }
    var match = OtherTests.search("ESR");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.61);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ESR: $10.61\n");
    }
    var match = OtherTests.search("CRP");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.31);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CRP: $10.31\n");
    }
    var match = OtherTests.search("TTG");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 125.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "TTG: $125.00\n");
    }
    var match = OtherTests.search("HP BREATH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 36.50);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HPBreathTest: $36.50\n");
    }
    var match = OtherTests.search("URIC");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.16);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Uric: $1.16\n");
    }
    var match = OtherTests.search("DIG");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.34);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Digoxin: $10.34\n");
    }
    var match = OtherTests.search("DILANT");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 17.13);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Dilantin: $17.13\n");
    }
    var match = OtherTests.search("LITHIUM");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 14.94);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Lithium: $14.94\n");
    }
    var match = OtherTests.search("MG|MAGNESIUM");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 6.79);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Mg: $6.79\n");
    }
    var match = OtherTests.search("CA125");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 22.72);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CA125: $22.72\n");
    }
    var match = OtherTests.search("CA19-9");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 20.88);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CA19-9: $20.88\n");
    }
    var match = OtherTests.search("CA15-3");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 21.25);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CA15-3: $21.25\n");
    }
    var match = OtherTests.search("FSH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 13.13);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "FSH: $13.13\n");
    }
    var match = OtherTests.search("LH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 12.41);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "LH: $12.41\n");
    }
    var match = OtherTests.search("PROLACTIN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 4.11);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Prolactin: $4.11\n");
    }
    var match = OtherTests.search("BLOOD GROUP");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 16.09);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Blood Group: $16.09\n");
    }
    var match = OtherTests.search("RH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.38);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Rh: $10.38\n");
    }
    var match = OtherTests.search("IPTH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 17.52);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "iPTH: $17.52\n");
    }
    var match = OtherTests.search("ENA");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 30.60);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ENA: $30.60\n");
    }
    var match = OtherTests.search("FACTOR 5");
    var match2 = OtherTests.search("FACTOR V");
    if ((match != -1) || (match2 != -1)) {
        newcost = Math.round(($('#Costs').val() * 1) + 52.04);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Factor 5 Leiden: $52.04\n");
    }
    var match = OtherTests.search("PROTEIN C");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 51.33);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Protein C: $51.33\n");
    }
    var match = OtherTests.search("PROTEIN S");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 38.31);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "PROTEIN S: $38.31\n");
    }
    var match = OtherTests.search("ANTITHROMBIN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 33.49);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Antithrombin 3: $33.49\n");
    }
    var match = OtherTests.search("MONOSPOT");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 17.10);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Mono: $17.10\n");
    }
    var match = OtherTests.search("CERULOPLASM");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.15);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Ceruloplasmin: $10.15\n");
    }
    var match = OtherTests.search("COPPER");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 49.19);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Copper: $49.19\n");
    }
    var match = OtherTests.search("SERUM PROTEIN EL");
    var match2 = OtherTests.search("SPEP");
    if ((match != -1) || (match2 != -1)) {
        newcost = Math.round(($('#Costs').val() * 1) + 26.54);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "SPEP: $26.54\n");
    }
    var match = OtherTests.search("TROPONIN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 15.05);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Troponin: $15.05\n");
    }
    var match = OtherTests.search("SEMEN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 15.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Semenanalysis: $15.00\n");
    }
    var match = OtherTests.search("VITAMIN D");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 12.13);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Vit D: $12.13\n");
    }
    var match = OtherTests.search("HBEAG");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 14.87);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HBeAg: $14.87\n");
    }
    var match = OtherTests.search("ANTI-HBEAG");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 15.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Anti-HBeAg: $15.00\n");
    }
    var match = OtherTests.search("HBV DNA");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 60.34);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HBV DNA: $60.34\n");
    }
    var match = OtherTests.search("DRVVT");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 14.01);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "DRVVT: $14.01\n");
    }
    var match = OtherTests.search("BNP");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 28.14);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "BNP: $28.14\n");
    }
    var match = OtherTests.search("PHOSPHATE");
    var match2 = OtherTests.search("PO4");
    if ((match != -1) || (match2 != -1)) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.64);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "PO4: $1.64\n");
    }
    var match = OtherTests.search("TESTOSTERONE");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 15.81);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Testosterone: $15.81\n");
    }
    var match = OtherTests.search("URINARY CALCIUM");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 5.48);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Urine Calcium: $5.48\n");
    }
    var match = OtherTests.search("DHEA");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 5.87);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "DHEAS: $5.87\n");
    }
    var match = OtherTests.search("VDRL");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 15.96);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "VDRL: $15.96\n");
    }
    var match = OtherTests.search("ESTRADIOL");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 22.43);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Estradiol: $22.43\n");
    }
    var match = OtherTests.search("AFP");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 9.31);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "AFP: $9.31\n");
    }
    var match = OtherTests.search("CEA");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 20.40);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CEA: $20.40\n");
    }
    var match = OtherTests.search("RF");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 8.41);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "RF: $8.41\n");
    }
    var match = OtherTests.search("ANA");
    var match2 = OtherTests.search("ANALYSIS");
    if ((match != -1) && (match2 == -1)) {
        newcost = Math.round(($('#Costs').val() * 1) + 23.27);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "ANA: $23.27(base+$75 per autoAb)\n");
    }
    var match = OtherTests.search("HEP C|HCV");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Hep C: ?$10.00\n");
    }
    var match = OtherTests.search("RUBELLA");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Rubella: ?$10.00\n");
    }
    var match = OtherTests.search("VZ");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "VZ IgG: ?$10.00\n");
    }
    var match = OtherTests.search("RPR|SYPHILIS");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 10.00);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "RPR: ?$10.00\n");
    }
    var match = OtherTests.search("ANTITRYPSIN|A1AT");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 20.06);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Alpha-1 antitrypsin: $20.06\n");
    }
    var match = OtherTests.search("MITOCHONDRIAL");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 23.82);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Anti-mitochondrial AB: $23.82 + $27.03/Extra Ab\n");
    }
    var match = OtherTests.search("LDH|LACTATE DEHYDROGENASE");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.62);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "LDH: $1.62\n");
    }
    var match = OtherTests.search("DDIMER|D DIMER|D-DIMER");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 23.27);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "D-dimer: $23.27\n");
    }
    var match = OtherTests.search("CCP");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 55);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "CCP: $55.00\n");
    }
    var match = OtherTests.search("THYROGLOBULIN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 27.90);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "THYROGLOBULIN: $27.90\n");
    }
    var match = OtherTests.search("VITAMIN C");
    var match2 = OtherTests.search("VIT C");
    var match3 = OtherTests.search("ASCORBIC");
    if ((match != -1) || (match2 != -1) || (match3 != -1))
        if (match != -1) {
            newcost = Math.round(($('#Costs').val() * 1) + 15.78);
            $('#Costs').val(newcost);
            AddIfMissingTitle('Costs', "Vit C: $15.78\n");
        }
    var match = OtherTests.search("TSH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 9.90);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "TSH: $9.90\n");
    }
    var match = OtherTests.search("FERRITIN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 2.97);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Ferritin: $2.97\n");
    }
    var match = OtherTests.search("LDH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "LDH: $1.28\n");
    }
    var match = OtherTests.search("CA,");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.16);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Calcium: $1.16\n");
    }
    var match = OtherTests.search("IRON");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Iron: $1.28\n");
    }
    var match = OtherTests.search("TRANSFERRIN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 5.22);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Transferrin: $5.22\n");
    }
    var match = OtherTests.search("PTH");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 9.39);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "PTH: $9.39\n");
    }
    var match = OtherTests.search("GGT");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "GGT: $1.28\n");
    }
    var match = OtherTests.search("VIT A");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 15.51);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Vit A: $15.51\n");
    }
    var match = OtherTests.search("BUN");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 1.28);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "BUN: $1.28\n");
    }
    var match = OtherTests.search("HLA");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 25.85);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "HLA: $25.85\n");
    }
    var match = OtherTests.search("KARYOTYPE");
    if (match != -1) {
        newcost = Math.round(($('#Costs').val() * 1) + 155.10);
        $('#Costs').val(newcost);
        AddIfMissingTitle('Costs', "Karyotype: $155.10\n");
    }
}, 1000);